@@ -41,14 +41,7 @@ void NextcloudWizard::init(KAccountsUiPlugin::UiType type)
         NextcloudController *helper = new NextcloudController(m_object);
 
         connect(helper, &NextcloudController::wizardFinished, this, [this](const QString &username, const QString &password, const QVariantMap &data) {
-            QWindow *window = qobject_cast<QWindow *>(m_object->rootObject());
-
-            if (window) {
-                window->close();
-            }
-
             m_object->deleteLater();
-
             Q_EMIT success(username, password, data);
         });
 
